available

Function available 

pub fn available() -> u64
Available on iOS or Linux or macOS or Windows only.
Get the number of bytes of available physical memory on this host.

Panics

This function may panic if any of the underlying platform-specific syscalls fail.

Examples found in repository?
examples/print-system-memory.rs (line 5)
4fn main() {
5    println!("Currently available: {} bytes\nTotal: {} bytes", available(), total());
6}