used

Function used 

pub fn used() -> u64
Available on iOS or Linux or macOS or Windows only.
Get the number of bytes of physical memory currently in use.

Panics

This function may panic if any of the underlying platform-specific syscalls fail.