pub struct Snapshot {
pub total: u64,
pub available: u64,
}Expand description
Snapshot of the host’s memory stats.
Fields
total: u64Total number of bytes of physical memory on the host system.
available: u64Number of bytes of available physical memory on the host system.
Implementations