pub fn total() -> u64
Get the total number of bytes of physical memory on this host.
This function may panic if any of the underlying platform-specific syscalls fail.
4fn main() { 5 println!("Currently available: {} bytes\nTotal: {} bytes", available(), total()); 6}